@@ -1,5 +1,12 @@
 from collections import OrderedDict
 
+# Representation of axis shifts
+axis_shift_left = -0.5
+axis_shift_right = 0.5
+axis_shift_center = 0
+# Characterizes valid shifts only
+valid_axis_shifts = [axis_shift_left, axis_shift_right, axis_shift_center]
+
 
 def assert_valid_comodo(ds):
     """Verify that the dataset meets comodo conventions
@@ -55,7 +62,7 @@ def get_axis_positions_and_coords(ds, axis_name):
     # center, left, right, or outer
     coords = {name: ds[name] for name in coord_names}
 
-    # some tortured logic for dealing with malforme c_grid_axis_shift
+    # some tortured logic for dealing with malformed c_grid_axis_shift
     # attributes such as produced by old versions of xmitgcm.
     # This should be a float (either -0.5 or 0.5)
     # this function returns that, or True of the attribute is set to
@@ -102,7 +109,7 @@ def get_axis_positions_and_coords(ds, axis_name):
             axis_coords["outer"] = name
         elif clen == axis_len - 1:
             axis_coords["inner"] = name
-        elif shift == -0.5:
+        elif shift == axis_shift_left:
             if clen == axis_len:
                 axis_coords["left"] = name
             else:
@@ -110,7 +117,7 @@ def get_axis_positions_and_coords(ds, axis_name):
                     "Left coordinate %s has incompatible "
                     "length %g (axis_len=%g)" % (name, clen, axis_len)
                 )
-        elif shift == 0.5:
+        elif shift == axis_shift_right:
             if clen == axis_len:
                 axis_coords["right"] = name
             else:
@@ -119,10 +126,21 @@ def get_axis_positions_and_coords(ds, axis_name):
                     "length %g (axis_len=%g)" % (name, clen, axis_len)
                 )
         else:
-            raise ValueError(
-                "Coordinate %s has invalid or missing "
-                "`c_grid_axis_shift` attribute `%s`" % (name, repr(shift))
-            )
+            if shift not in valid_axis_shifts:
+                # string representing valid axis shifts
+                valids = str(valid_axis_shifts)[1:-1]
+
+                raise ValueError(
+                    "Coordinate %s has invalid "
+                    "`c_grid_axis_shift` attribute `%s`. "
+                    "`c_grid_axis_shift` must be one of: %s"
+                    % (name, repr(shift), valids)
+                )
+            else:
+                raise ValueError(
+                    "Coordinate %s has missing "
+                    "`c_grid_axis_shift` attribute `%s`" % (name, repr(shift))
+                )
     return axis_coords
 
 
