@@ -448,7 +448,7 @@ class GridUFunc:
 
     def __call__(
         self,
-        grid: "Grid" = None,
+        grid: Optional["Grid"] = None,
         *args: xr.DataArray,
         axis: Sequence[str],
         **kwargs,
@@ -473,7 +473,9 @@ class GridUFunc:
 
 
 def as_grid_ufunc(
-    signature: str = "", boundary_width: Mapping[str, Tuple[int, int]] = None, **kwargs
+    signature: str = "",
+    boundary_width: Optional[Mapping[str, Tuple[int, int]]] = None,
+    **kwargs,
 ) -> Callable:
     """
     Decorator which turns a numpy ufunc into a "grid-aware ufunc".
@@ -555,18 +557,18 @@ def as_grid_ufunc(
 def apply_as_grid_ufunc(
     func: Callable,
     *args: Union[xr.DataArray, Dict[str, xr.DataArray]],
-    axis: Sequence[Sequence[str]] = None,
-    grid: "Grid" = None,
+    axis: Optional[Sequence[Sequence[str]]] = None,
+    grid: Optional["Grid"] = None,
     signature: Union[str, _GridUFuncSignature] = "",
-    boundary_width: Mapping[str, Tuple[int, int]] = None,
-    boundary: Union[str, Mapping[str, str]] = None,
-    fill_value: Union[float, Mapping[str, float]] = None,
+    boundary_width: Optional[Mapping[str, Tuple[int, int]]] = None,
+    boundary: Optional[Union[str, Mapping[str, str]]] = None,
+    fill_value: Optional[Union[float, Mapping[str, float]]] = None,
     keep_coords: bool = True,
     dask: Literal["forbidden", "parallelized", "allowed"] = "forbidden",
     map_overlap: bool = False,
     pad_before_func: bool = True,
-    other_component: Union[
-        Dict[str, xr.DataArray], Sequence[Dict[str, xr.DataArray]]
+    other_component: Optional[
+        Union[Dict[str, xr.DataArray], Sequence[Dict[str, xr.DataArray]]]
     ] = None,
     **kwargs,
 ) -> List[Any]:
@@ -909,7 +911,7 @@ def _pad_then_rechunk(
 
 def _is_dim_chunked(a, dim):
     # TODO this func can't handle Datasets - it will error if you check multiple variables with different chunking
-    return len(a.variable.chunksizes[dim]) > 0
+    return len(a.variable.chunksizes[dim]) > 1
 
 
 def _has_chunked_core_dims(obj: xr.DataArray, core_dims: Sequence[str]) -> bool:
@@ -1001,7 +1003,8 @@ def _check_if_length_would_change(signature: _GridUFuncSignature):
     if any(pos in DISALLOWED_OVERLAP_POSITIONS for pos in all_ax_positions):
         raise NotImplementedError(
             "Cannot chunk along a core dimension for a grid ufunc which has a signature which "
-            f"includes one of the axis positions {DISALLOWED_OVERLAP_POSITIONS}"
+            f"includes one of the axis positions {DISALLOWED_OVERLAP_POSITIONS}."
+            "Consider rechunking to a single chunk along this dimension if possible."
         )
 
 
@@ -1111,7 +1114,7 @@ def _reattach_coords(
     results_with_coords = []
     for res in results:
 
-        # padding strips all coordinates (inlcuding dimension coordinates).
+        # padding strips all coordinates (including dimension coordinates).
         # Here we centrally restore them from the grid._ds.
         all_matching_coords = {
             coord: da_coord
